@@ -19,9 +19,9 @@ def stream_url(url: str, timeout: int = 3) -> None:
     # exit code 0 means no problem
     logger = get_logger()
     try:
-        json.dumps({"url": url,
-                    "returncode": out.returncode,
-                    "html": out.stdout.decode("utf-8")})
+        print(json.dumps({"url": url,
+                          "returncode": out.returncode,
+                          "html": out.stdout.decode("utf-8")}))
     except UnicodeDecodeError:
         logger.error(
             "[*] Error, could not decode {} and so skipping it".format(url))
